==> kdelibs-2.1.2.tar.bz2: kdelibs-2.1.2/khtml/rendering/render_br.cpp <==
/**
 * This file is part of the DOM implementation for KDE.
 *
 * Copyright (C) 2000 Lars Knoll (knoll@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: render_br.cpp,v 1.9 2001/02/07 18:59:06 knoll Exp $
 */
#include "render_br.h"
#include "dom_stringimpl.h"
#include "qfontmetrics.h"

using namespace khtml;


RenderBR::RenderBR()
    : RenderText(new DOM::DOMStringImpl(QChar('\n')))
{
    m_hasReturn = true;
}

RenderBR::~RenderBR()
{
}

short RenderBR::verticalPositionHint() const
{
    if (previousSibling() && !previousSibling()->isBR() && !previousSibling()->isFloating())
        return 0;
    else
        return RenderText::verticalPositionHint();
}

void RenderBR::cursorPos(int /*offset*/, int &_x, int &_y, int &height)
{
    if (previousSibling() && !previousSibling()->isBR() && !previousSibling()->isFloating()) {
        int offset = 0;
        if (previousSibling()->isText())
            offset = static_cast<RenderText*>(previousSibling())->length();

        previousSibling()->cursorPos(offset,_x,_y,height);
        return;
    }

    int absx, absy;
    absolutePosition(absx,absy);
    if (absx == -1) {
        // we don't know out absoluate position, and there is not point returning
        // just a relative one
        _x = _y = -1;
    }
    else {
        _x += absx;
        _y += absy;
    }
    height = RenderText::verticalPositionHint();

}

==> kdelibs-2.2.2.tar.bz2: kdelibs-2.2.2/khtml/rendering/render_br.cpp <==
/**
 * This file is part of the DOM implementation for KDE.
 *
 * Copyright (C) 2000 Lars Knoll (knoll@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: render_br.cpp,v 1.13 2001/07/12 21:05:10 knoll Exp $
 */
#include "render_br.h"
#include "dom_stringimpl.h"
#include "qfontmetrics.h"

using namespace khtml;


RenderBR::RenderBR()
    : RenderText(new DOM::DOMStringImpl(QChar('\n')))
{
    m_hasReturn = true;
}

RenderBR::~RenderBR()
{
}

void RenderBR::cursorPos(int /*offset*/, int &_x, int &_y, int &height)
{
    if (previousSibling() && !previousSibling()->isBR() && !previousSibling()->isFloating()) {
        int offset = 0;
        if (previousSibling()->isText())
            offset = static_cast<RenderText*>(previousSibling())->length();

        previousSibling()->cursorPos(offset,_x,_y,height);
        return;
    }

    int absx, absy;
    absolutePosition(absx,absy);
    if (absx == -1) {
        // we don't know out absoluate position, and there is not point returning
        // just a relative one
        _x = _y = -1;
    }
    else {
        _x += absx;
        _y += absy;
    }
    height = RenderText::verticalPositionHint( false );

}
